//**************************************************************************
// ﾌｧｲﾙ内容     I2C液晶 AQM0802 制御ライブラリ Wire1版
// バージョン   Ver.1.00
// Date         2024.01.01
// Copyright    ジャパンマイコンカーラリー実行委員会
// ライセンス   This software is released under the MIT License.
//              http://opensource.org/licenses/mit-license.php
//**************************************************************************

//======================================
// インクルード
//======================================
#include "MCR_AQM0802_wire1.h"

//**********************************************************************
// AQM0802へコマンド書き込み
//**********************************************************************
void MCR_AQM0802_WIRE1::writeCmd(byte command) {
  Wire1.beginTransmission( 0x3e );
  Wire1.write( 0x00 );
  Wire1.write(command);
  Wire1.endTransmission();
  delayMicroseconds( 30 );
}

//**********************************************************************
// AQM0802へ表示データ書き込み
//**********************************************************************
void MCR_AQM0802_WIRE1::writeData(byte data) {
  Wire1.beginTransmission( 0x3e );
  Wire1.write( 0x40 );
  Wire1.write( data );
  Wire1.endTransmission();
  delayMicroseconds( 100 );
}

//**********************************************************************
// コントラストセット 0～63 5Vのときは11～12がお勧めです
//**********************************************************************
void MCR_AQM0802_WIRE1::setContrast( byte c ) {
  if( c <  1 ) c =  1;
  if( c > 63 ) c = 63;
  contrast = c;

  writeCmd( 0x39 );                             // Function set
  writeCmd( 0x70 | ( contrast & 0x0f) );        // Contrast set(bit3,2,1,0)
  writeCmd( 0x54 | ( (contrast>>4) & 0x03) );   // Power/ICON/Contrast set(bit5,4)
  writeCmd( 0x38 );                             // Function set
}

//**********************************************************************
// 液晶の文字位置セット x=0がいちばん左、y=0がいちばん上
//**********************************************************************
void MCR_AQM0802_WIRE1::setPosition( char x, char y ) {
  byte yy = 0x00;

  if( x >= LCD1_MAX_X ) return;
  if( y >= LCD1_MAX_Y ) return;

  lcdPosition_x = x;
  lcdPosition_y = y;  

  if( y == 1 ) {
    yy = 0x40;
  } else if( y == 2 ) {
    yy = 0x14;
  } else if( y == 3 ) {
    yy = 0x54;
  }
  writeCmd( 0x80 + x + yy );
}

//**********************************************************************
// AQM0802用のprintf関数
//**********************************************************************
int MCR_AQM0802_WIRE1::printf( const char *format, ... ) {
    va_list argptr;
    char    *p;
    int     ret = 0;
    char    work[32];   // 一時作業エリア

    va_start(argptr, format);
    ret = vsprintf( work, format, argptr );
    va_end(argptr);

    if( ret > 0 ) {
      // vsprintfが正常なら液晶バッファへ転送
      p = work;
      while( *p ) {
        writeData( *p++ );
        lcdPosition_x++;
        if( lcdPosition_x >= LCD1_MAX_X ) {
          lcdPosition_x = 0;
          lcdPosition_y++;
          if( lcdPosition_y >= LCD1_MAX_Y ) {
            lcdPosition_y = 0;
          }
          setPosition( 0 , lcdPosition_y );
        }
      }
    }
    return ret;
}

//**********************************************************************
// AQM0802　初期化とコントラストセット
//**********************************************************************
void MCR_AQM0802_WIRE1::init( byte c ) {
  begin( c );
}

void MCR_AQM0802_WIRE1::begin( byte c ) {
  if( c <  1 ) c =  1;
  if( c > 63 ) c = 63;
  contrast = c;

  delay( 50 );
  Wire1.begin();
  writeCmd( 0x38 );     // Function set
  writeCmd( 0x39 );     // Function set
  writeCmd( 0x14 );     // Internal OSC frequency
  writeCmd( 0x70 | ( contrast & 0x0f) );      // Contrast set
  writeCmd( 0x54 | ( (contrast>>4) & 0x03) ); // Power/ICON/Contrast set
  writeCmd( 0x6c );     // Follower control
  delay( 200 );
  writeCmd( 0x38 );     // Function set
  writeCmd( 0x0c );     // Display On/OFF control
  writeCmd( 0x01);      // Clear Display
  delay( 15 );
}
